/****************************************************************************
** Meta object code from reading C++ file 'DeclarativeDragDropEvent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/draganddrop/DeclarativeDragDropEvent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeclarativeDragDropEvent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24DeclarativeDragDropEventE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeDragDropEvent::qt_create_metaobjectdata<qt_meta_tag_ZN24DeclarativeDragDropEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeDragDropEvent",
        "QML.Element",
        "DragDropEvent",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "DragDropEvent cannot be created from QML.",
        "accept",
        "",
        "action",
        "ignore",
        "x",
        "y",
        "buttons",
        "modifiers",
        "mimeData",
        "DeclarativeMimeData*",
        "possibleActions",
        "Qt::DropActions",
        "proposedAction",
        "Qt::DropAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'accept'
        QtMocHelpers::SlotData<void(int)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'ignore'
        QtMocHelpers::SlotData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'y'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'buttons'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'modifiers'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'mimeData'
        QtMocHelpers::PropertyData<DeclarativeMimeData*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'possibleActions'
        QtMocHelpers::PropertyData<Qt::DropActions>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'proposedAction'
        QtMocHelpers::PropertyData<Qt::DropAction>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeDragDropEvent, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeDragDropEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DeclarativeDragDropEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DeclarativeDragDropEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24DeclarativeDragDropEventE_t>.metaTypes,
    nullptr
} };

void DeclarativeDragDropEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeDragDropEvent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accept((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->ignore(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DeclarativeMimeData* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->buttons(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->modifiers(); break;
        case 4: *reinterpret_cast<DeclarativeMimeData**>(_v) = _t->mimeData(); break;
        case 5: *reinterpret_cast<Qt::DropActions*>(_v) = _t->possibleActions(); break;
        case 6: *reinterpret_cast<Qt::DropAction*>(_v) = _t->proposedAction(); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeDragDropEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeDragDropEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DeclarativeDragDropEventE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativeDragDropEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
