/****************************************************************************
** Meta object code from reading C++ file 'calendareventsplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeclarative-6.25.0/src/calendarevents/calendareventsplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendareventsplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarEvents::CalendarEventsPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarEvents::CalendarEventsPlugin",
        "dataReady",
        "",
        "QMultiHash<QDate,CalendarEvents::EventData>",
        "data",
        "eventModified",
        "CalendarEvents::EventData",
        "modifiedEvent",
        "eventRemoved",
        "uid",
        "alternateCalendarDateReady",
        "QHash<QDate,QCalendar::YearMonthDay>",
        "subLabelReady",
        "QHash<QDate,SubLabel>",
        "SubLabelPriority",
        "Low",
        "Default",
        "High",
        "Urgent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataReady'
        QtMocHelpers::SignalData<void(const QMultiHash<QDate,CalendarEvents::EventData> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'eventModified'
        QtMocHelpers::SignalData<void(const CalendarEvents::EventData &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'eventRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'alternateCalendarDateReady'
        QtMocHelpers::SignalData<void(const QHash<QDate,QCalendar::YearMonthDay> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 4 },
        }}),
        // Signal 'subLabelReady'
        QtMocHelpers::SignalData<void(const QHash<QDate,SubLabel> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SubLabelPriority'
        QtMocHelpers::EnumData<enum SubLabelPriority>(14, 14, QMC::EnumIsScoped).add({
            {   15, SubLabelPriority::Low },
            {   16, SubLabelPriority::Default },
            {   17, SubLabelPriority::High },
            {   18, SubLabelPriority::Urgent },
        }),
    };
    return QtMocHelpers::metaObjectData<CalendarEventsPlugin, qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarEvents::CalendarEventsPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t>.metaTypes,
    nullptr
} };

void CalendarEvents::CalendarEventsPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarEventsPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataReady((*reinterpret_cast<std::add_pointer_t<QMultiHash<QDate,CalendarEvents::EventData>>>(_a[1]))); break;
        case 1: _t->eventModified((*reinterpret_cast<std::add_pointer_t<CalendarEvents::EventData>>(_a[1]))); break;
        case 2: _t->eventRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->alternateCalendarDateReady((*reinterpret_cast<std::add_pointer_t<QHash<QDate,QCalendar::YearMonthDay>>>(_a[1]))); break;
        case 4: _t->subLabelReady((*reinterpret_cast<std::add_pointer_t<QHash<QDate,SubLabel>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarEventsPlugin::*)(const QMultiHash<QDate,CalendarEvents::EventData> & )>(_a, &CalendarEventsPlugin::dataReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarEventsPlugin::*)(const CalendarEvents::EventData & )>(_a, &CalendarEventsPlugin::eventModified, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarEventsPlugin::*)(const QString & )>(_a, &CalendarEventsPlugin::eventRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarEventsPlugin::*)(const QHash<QDate,QCalendar::YearMonthDay> & )>(_a, &CalendarEventsPlugin::alternateCalendarDateReady, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarEventsPlugin::*)(const QHash<QDate,SubLabel> & )>(_a, &CalendarEventsPlugin::subLabelReady, 4))
            return;
    }
}

const QMetaObject *CalendarEvents::CalendarEventsPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarEvents::CalendarEventsPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CalendarEvents20CalendarEventsPluginE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CalendarEvents::CalendarEventsPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void CalendarEvents::CalendarEventsPlugin::dataReady(const QMultiHash<QDate,CalendarEvents::EventData> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CalendarEvents::CalendarEventsPlugin::eventModified(const CalendarEvents::EventData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CalendarEvents::CalendarEventsPlugin::eventRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CalendarEvents::CalendarEventsPlugin::alternateCalendarDateReady(const QHash<QDate,QCalendar::YearMonthDay> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CalendarEvents::CalendarEventsPlugin::subLabelReady(const QHash<QDate,SubLabel> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
