/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<keysequencehelper.h>)
#  include <keysequencehelper.h>
#endif
#if __has_include(<keysequencevalidator.h>)
#  include <keysequencevalidator.h>
#endif
#if __has_include(<translationcontext.h>)
#  include <translationcontext.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_private_kquickcontrols()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<KeySequenceHelper>("org.kde.private.kquickcontrols", 2);
    qmlRegisterTypesAndRevisions<KeySequenceValidator>("org.kde.private.kquickcontrols", 2);
    qmlRegisterTypesAndRevisions<TranslationContext>("org.kde.private.kquickcontrols", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.private.kquickcontrols", 2, 0);
}

static const QQmlModuleRegistration orgkdeprivatekquickcontrolsRegistration("org.kde.private.kquickcontrols", qml_register_types_org_kde_private_kquickcontrols);
