/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<DeclarativeDragArea.h>)
#  include <DeclarativeDragArea.h>
#endif
#if __has_include(<DeclarativeDragDropEvent.h>)
#  include <DeclarativeDragDropEvent.h>
#endif
#if __has_include(<DeclarativeDropArea.h>)
#  include <DeclarativeDropArea.h>
#endif
#if __has_include(<DeclarativeMimeData.h>)
#  include <DeclarativeMimeData.h>
#endif
#if __has_include(<MimeDataWrapper.h>)
#  include <MimeDataWrapper.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_draganddrop()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DeclarativeDragArea>("org.kde.draganddrop", 2);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.draganddrop", 2);
    qmlRegisterTypesAndRevisions<DeclarativeDragDropEvent>("org.kde.draganddrop", 2);
    qmlRegisterTypesAndRevisions<DeclarativeDropArea>("org.kde.draganddrop", 2);
    qmlRegisterTypesAndRevisions<DeclarativeMimeData>("org.kde.draganddrop", 2);
    qmlRegisterTypesAndRevisions<MimeDataForign>("org.kde.draganddrop", 2);
    qmlRegisterTypesAndRevisions<MimeDataWrapper>("org.kde.draganddrop", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.draganddrop", 2, 0);
}

static const QQmlModuleRegistration orgkdedraganddropRegistration("org.kde.draganddrop", qml_register_types_org_kde_draganddrop);
