/****************************************************************************
** Meta object code from reading C++ file 'DeclarativeDropArea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/draganddrop/DeclarativeDropArea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeclarativeDropArea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19DeclarativeDropAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeDropArea::qt_create_metaobjectdata<qt_meta_tag_ZN19DeclarativeDropAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeDropArea",
        "QML.Element",
        "DropArea",
        "dragEnter",
        "",
        "DeclarativeDragDropEvent*",
        "event",
        "dragLeave",
        "dragMove",
        "drop",
        "enabledChanged",
        "preventStealingChanged",
        "containsDragChanged",
        "contained",
        "temporaryInhibitParent",
        "inhibit",
        "enabled",
        "preventStealing",
        "containsDrag"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dragEnter'
        QtMocHelpers::SignalData<void(DeclarativeDragDropEvent *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'dragLeave'
        QtMocHelpers::SignalData<void(DeclarativeDragDropEvent *)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'dragMove'
        QtMocHelpers::SignalData<void(DeclarativeDragDropEvent *)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'drop'
        QtMocHelpers::SignalData<void(DeclarativeDragDropEvent *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preventStealingChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containsDragChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'temporaryInhibitParent'
        QtMocHelpers::SlotData<void(bool)>(14, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'preventStealing'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'containsDrag'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeDropArea, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeDropArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeDropAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeDropAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DeclarativeDropAreaE_t>.metaTypes,
    nullptr
} };

void DeclarativeDropArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeDropArea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dragEnter((*reinterpret_cast<std::add_pointer_t<DeclarativeDragDropEvent*>>(_a[1]))); break;
        case 1: _t->dragLeave((*reinterpret_cast<std::add_pointer_t<DeclarativeDragDropEvent*>>(_a[1]))); break;
        case 2: _t->dragMove((*reinterpret_cast<std::add_pointer_t<DeclarativeDragDropEvent*>>(_a[1]))); break;
        case 3: _t->drop((*reinterpret_cast<std::add_pointer_t<DeclarativeDragDropEvent*>>(_a[1]))); break;
        case 4: _t->enabledChanged(); break;
        case 5: _t->preventStealingChanged(); break;
        case 6: _t->containsDragChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->temporaryInhibitParent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)(DeclarativeDragDropEvent * )>(_a, &DeclarativeDropArea::dragEnter, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)(DeclarativeDragDropEvent * )>(_a, &DeclarativeDropArea::dragLeave, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)(DeclarativeDragDropEvent * )>(_a, &DeclarativeDropArea::dragMove, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)(DeclarativeDragDropEvent * )>(_a, &DeclarativeDropArea::drop, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)()>(_a, &DeclarativeDropArea::enabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)()>(_a, &DeclarativeDropArea::preventStealingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDropArea::*)(bool )>(_a, &DeclarativeDropArea::containsDragChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->preventStealing(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->containsDrag(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setPreventStealing(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeDropArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeDropArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeDropAreaE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int DeclarativeDropArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeDropArea::dragEnter(DeclarativeDragDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeDropArea::dragLeave(DeclarativeDragDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeDropArea::dragMove(DeclarativeDragDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeDropArea::drop(DeclarativeDragDropEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeDropArea::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DeclarativeDropArea::preventStealingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DeclarativeDropArea::containsDragChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
