/****************************************************************************
** Meta object code from reading C++ file 'qimageitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/kquickcontrolsaddons/qimageitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qimageitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10QImageItemE_t {};
} // unnamed namespace

template <> constexpr inline auto QImageItem::qt_create_metaobjectdata<qt_meta_tag_ZN10QImageItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QImageItem",
        "QML.Element",
        "auto",
        "nativeWidthChanged",
        "",
        "nativeHeightChanged",
        "fillModeChanged",
        "imageChanged",
        "nullChanged",
        "paintedWidthChanged",
        "paintedHeightChanged",
        "updatePaintedRect",
        "image",
        "QImage",
        "nativeWidth",
        "nativeHeight",
        "paintedWidth",
        "paintedHeight",
        "fillMode",
        "FillMode",
        "null",
        "Stretch",
        "PreserveAspectFit",
        "PreserveAspectCrop",
        "Tile",
        "TileVertically",
        "TileHorizontally",
        "Pad"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nativeWidthChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nativeHeightChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillModeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nullChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintedWidthChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintedHeightChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePaintedRect'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'image'
        QtMocHelpers::PropertyData<QImage>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'nativeWidth'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'nativeHeight'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'paintedWidth'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'paintedHeight'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'fillMode'
        QtMocHelpers::PropertyData<enum FillMode>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'null'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FillMode'
        QtMocHelpers::EnumData<enum FillMode>(19, 19, QMC::EnumFlags{}).add({
            {   21, FillMode::Stretch },
            {   22, FillMode::PreserveAspectFit },
            {   23, FillMode::PreserveAspectCrop },
            {   24, FillMode::Tile },
            {   25, FillMode::TileVertically },
            {   26, FillMode::TileHorizontally },
            {   27, FillMode::Pad },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QImageItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QImageItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QImageItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QImageItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10QImageItemE_t>.metaTypes,
    nullptr
} };

void QImageItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QImageItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nativeWidthChanged(); break;
        case 1: _t->nativeHeightChanged(); break;
        case 2: _t->fillModeChanged(); break;
        case 3: _t->imageChanged(); break;
        case 4: _t->nullChanged(); break;
        case 5: _t->paintedWidthChanged(); break;
        case 6: _t->paintedHeightChanged(); break;
        case 7: _t->updatePaintedRect(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::nativeWidthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::nativeHeightChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::fillModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::imageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::nullChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::paintedWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QImageItem::*)()>(_a, &QImageItem::paintedHeightChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QImage*>(_v) = _t->image(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->nativeWidth(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->nativeHeight(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->paintedWidth(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->paintedHeight(); break;
        case 5: *reinterpret_cast<enum FillMode*>(_v) = _t->fillMode(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isNull(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImage(*reinterpret_cast<QImage*>(_v)); break;
        case 5: _t->setFillMode(*reinterpret_cast<enum FillMode*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetImage(); break;
        default: break;
        }
    }
}

const QMetaObject *QImageItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QImageItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QImageItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int QImageItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QImageItem::nativeWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QImageItem::nativeHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QImageItem::fillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QImageItem::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QImageItem::nullChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QImageItem::paintedWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QImageItem::paintedHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
