/****************************************************************************
** Meta object code from reading C++ file 'DeclarativeDragArea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/draganddrop/DeclarativeDragArea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeclarativeDragArea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19DeclarativeDragAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeDragArea::qt_create_metaobjectdata<qt_meta_tag_ZN19DeclarativeDragAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeDragArea",
        "QML.Element",
        "DragArea",
        "dragStarted",
        "",
        "delegateChanged",
        "dragActiveChanged",
        "sourceChanged",
        "targetChanged",
        "dataChanged",
        "enabledChanged",
        "drop",
        "action",
        "supportedActionsChanged",
        "defaultActionChanged",
        "startDragDistanceChanged",
        "delegateImageChanged",
        "delegate",
        "QQuickItem*",
        "source",
        "target",
        "mimeData",
        "DeclarativeMimeData*",
        "enabled",
        "supportedActions",
        "Qt::DropActions",
        "defaultAction",
        "Qt::DropAction",
        "startDragDistance",
        "delegateImage",
        "QVariant",
        "dragActive"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dragStarted'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'delegateChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragActiveChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'drop'
        QtMocHelpers::SignalData<void(int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'supportedActionsChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultActionChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startDragDistanceChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'delegateImageChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'delegate'
        QtMocHelpers::PropertyData<QQuickItem*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'source'
        QtMocHelpers::PropertyData<QQuickItem*>(19, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'target'
        QtMocHelpers::PropertyData<QQuickItem*>(20, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'mimeData'
        QtMocHelpers::PropertyData<DeclarativeMimeData*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'supportedActions'
        QtMocHelpers::PropertyData<Qt::DropActions>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'defaultAction'
        QtMocHelpers::PropertyData<Qt::DropAction>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'startDragDistance'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'delegateImage'
        QtMocHelpers::PropertyData<QVariant>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'dragActive'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeDragArea, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeDragArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeDragAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeDragAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DeclarativeDragAreaE_t>.metaTypes,
    nullptr
} };

void DeclarativeDragArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeDragArea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dragStarted(); break;
        case 1: _t->delegateChanged(); break;
        case 2: _t->dragActiveChanged(); break;
        case 3: _t->sourceChanged(); break;
        case 4: _t->targetChanged(); break;
        case 5: _t->dataChanged(); break;
        case 6: _t->enabledChanged(); break;
        case 7: _t->drop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->supportedActionsChanged(); break;
        case 9: _t->defaultActionChanged(); break;
        case 10: _t->startDragDistanceChanged(); break;
        case 11: _t->delegateImageChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::dragStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::delegateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::dragActiveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::sourceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::targetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::dataChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::enabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)(int )>(_a, &DeclarativeDragArea::drop, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::supportedActionsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::defaultActionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::startDragDistanceChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDragArea::*)()>(_a, &DeclarativeDragArea::delegateImageChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DeclarativeMimeData* >(); break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->delegate(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->source(); break;
        case 2: *reinterpret_cast<QQuickItem**>(_v) = _t->source(); break;
        case 3: *reinterpret_cast<DeclarativeMimeData**>(_v) = _t->mimeData(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 5: *reinterpret_cast<Qt::DropActions*>(_v) = _t->supportedActions(); break;
        case 6: *reinterpret_cast<Qt::DropAction*>(_v) = _t->defaultAction(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->startDragDistance(); break;
        case 8: *reinterpret_cast<QVariant*>(_v) = _t->delegateImage(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->dragActive(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDelegate(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setSource(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 4: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setSupportedActions(*reinterpret_cast<Qt::DropActions*>(_v)); break;
        case 6: _t->setDefaultAction(*reinterpret_cast<Qt::DropAction*>(_v)); break;
        case 7: _t->setStartDragDistance(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setDelegateImage(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetDelegate(); break;
        case 1: _t->resetSource(); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeDragArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeDragArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeDragAreaE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int DeclarativeDragArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeDragArea::dragStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeclarativeDragArea::delegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DeclarativeDragArea::dragActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DeclarativeDragArea::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DeclarativeDragArea::targetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DeclarativeDragArea::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DeclarativeDragArea::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DeclarativeDragArea::drop(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeclarativeDragArea::supportedActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DeclarativeDragArea::defaultActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DeclarativeDragArea::startDragDistanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DeclarativeDragArea::delegateImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
