/****************************************************************************
** Meta object code from reading C++ file 'keysequencevalidator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../kdeclarative-6.25.0/src/qmlcontrols/kquickcontrols/private/keysequencevalidator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keysequencevalidator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20KeySequenceValidatorE_t {};
} // unnamed namespace

template <> constexpr inline auto KeySequenceValidator::qt_create_metaobjectdata<qt_meta_tag_ZN20KeySequenceValidatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeySequenceValidator",
        "QML.Element",
        "auto",
        "currentKeySequenceChanged",
        "",
        "validateTypesChanged",
        "error",
        "title",
        "message",
        "question",
        "finished",
        "QKeySequence",
        "keySequence",
        "validateSequence",
        "accept",
        "reject",
        "currentKeySequence",
        "validateTypes",
        "KeySequenceEnums::ShortcutTypes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentKeySequenceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'validateTypesChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'question'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(const QKeySequence &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'validateSequence'
        QtMocHelpers::MethodData<void(const QKeySequence &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'accept'
        QtMocHelpers::MethodData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'reject'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentKeySequence'
        QtMocHelpers::PropertyData<QKeySequence>(16, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'validateTypes'
        QtMocHelpers::PropertyData<KeySequenceEnums::ShortcutTypes>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KeySequenceValidator, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN20KeySequenceValidatorE[] = {
    QMetaObject::SuperData::link<KeySequenceEnums::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KeySequenceValidator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KeySequenceValidatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KeySequenceValidatorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN20KeySequenceValidatorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KeySequenceValidatorE_t>.metaTypes,
    nullptr
} };

void KeySequenceValidator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeySequenceValidator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentKeySequenceChanged(); break;
        case 1: _t->validateTypesChanged(); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->question((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->finished((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 5: _t->validateSequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 6: _t->accept(); break;
        case 7: _t->reject(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeySequenceValidator::*)()>(_a, &KeySequenceValidator::currentKeySequenceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeySequenceValidator::*)()>(_a, &KeySequenceValidator::validateTypesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeySequenceValidator::*)(const QString & , const QString & )>(_a, &KeySequenceValidator::error, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeySequenceValidator::*)(const QString & , const QString & )>(_a, &KeySequenceValidator::question, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeySequenceValidator::*)(const QKeySequence & )>(_a, &KeySequenceValidator::finished, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QKeySequence*>(_v) = _t->currentKeySequence(); break;
        case 1: *reinterpret_cast<KeySequenceEnums::ShortcutTypes*>(_v) = _t->validateTypes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentKeySequence(*reinterpret_cast<QKeySequence*>(_v)); break;
        case 1: _t->setValidateTypes(*reinterpret_cast<KeySequenceEnums::ShortcutTypes*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeySequenceValidator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeySequenceValidator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KeySequenceValidatorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KeySequenceValidator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KeySequenceValidator::currentKeySequenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeySequenceValidator::validateTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeySequenceValidator::error(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KeySequenceValidator::question(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KeySequenceValidator::finished(const QKeySequence & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
