/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<clipboard.h>)
#  include <clipboard.h>
#endif
#if __has_include(<mouseeventlistener.h>)
#  include <mouseeventlistener.h>
#endif
#if __has_include(<qimageitem.h>)
#  include <qimageitem.h>
#endif
#if __has_include(<qpixmapitem.h>)
#  include <qpixmapitem.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kquickcontrolsaddons()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Clipboard>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterTypesAndRevisions<KDeclarativeMouseEvent>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterTypesAndRevisions<KDeclarativeWheelEvent>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterTypesAndRevisions<MouseEventListener>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterTypesAndRevisions<QImageItem>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterEnum<QImageItem::FillMode>("QImageItem::FillMode");
    qmlRegisterTypesAndRevisions<QPixmapItem>("org.kde.kquickcontrolsaddons", 2);
    qmlRegisterEnum<QPixmapItem::FillMode>("QPixmapItem::FillMode");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kquickcontrolsaddons", 2, 0);
}

static const QQmlModuleRegistration orgkdekquickcontrolsaddonsRegistration("org.kde.kquickcontrolsaddons", qml_register_types_org_kde_kquickcontrolsaddons);
