/****************************************************************************
** Meta object code from reading C++ file 'mouseeventlistener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/kquickcontrolsaddons/mouseeventlistener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mouseeventlistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22KDeclarativeMouseEventE_t {};
} // unnamed namespace

template <> constexpr inline auto KDeclarativeMouseEvent::qt_create_metaobjectdata<qt_meta_tag_ZN22KDeclarativeMouseEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDeclarativeMouseEvent",
        "QML.Element",
        "anonymous",
        "acceptedChanged",
        "",
        "x",
        "y",
        "screenX",
        "screenY",
        "button",
        "buttons",
        "Qt::MouseButtons",
        "modifiers",
        "Qt::KeyboardModifiers",
        "screen",
        "QScreen*",
        "accepted",
        "source"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'acceptedChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'y'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'screenX'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'screenY'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'button'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'buttons'
        QtMocHelpers::PropertyData<Qt::MouseButtons>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'modifiers'
        QtMocHelpers::PropertyData<Qt::KeyboardModifiers>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'screen'
        QtMocHelpers::PropertyData<QScreen*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'accepted'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'source'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KDeclarativeMouseEvent, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KDeclarativeMouseEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KDeclarativeMouseEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KDeclarativeMouseEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KDeclarativeMouseEventE_t>.metaTypes,
    nullptr
} };

void KDeclarativeMouseEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KDeclarativeMouseEvent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->acceptedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KDeclarativeMouseEvent::*)()>(_a, &KDeclarativeMouseEvent::acceptedChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->screenX(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->screenY(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->button(); break;
        case 5: *reinterpret_cast<Qt::MouseButtons*>(_v) = _t->buttons(); break;
        case 6: *reinterpret_cast<Qt::KeyboardModifiers*>(_v) = _t->modifiers(); break;
        case 7: *reinterpret_cast<QScreen**>(_v) = _t->screen(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isAccepted(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->source(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setAccepted(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KDeclarativeMouseEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDeclarativeMouseEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KDeclarativeMouseEventE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDeclarativeMouseEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KDeclarativeMouseEvent::acceptedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN22KDeclarativeWheelEventE_t {};
} // unnamed namespace

template <> constexpr inline auto KDeclarativeWheelEvent::qt_create_metaobjectdata<qt_meta_tag_ZN22KDeclarativeWheelEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDeclarativeWheelEvent",
        "QML.Element",
        "anonymous",
        "x",
        "y",
        "screenX",
        "screenY",
        "deltaX",
        "deltaY",
        "delta",
        "buttons",
        "Qt::MouseButtons",
        "modifiers",
        "Qt::KeyboardModifiers",
        "orientation",
        "Qt::Orientation"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'y'
        QtMocHelpers::PropertyData<int>(4, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'screenX'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'screenY'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deltaX'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deltaY'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'delta'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'buttons'
        QtMocHelpers::PropertyData<Qt::MouseButtons>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'modifiers'
        QtMocHelpers::PropertyData<Qt::KeyboardModifiers>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'orientation'
        QtMocHelpers::PropertyData<Qt::Orientation>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KDeclarativeWheelEvent, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KDeclarativeWheelEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KDeclarativeWheelEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KDeclarativeWheelEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KDeclarativeWheelEventE_t>.metaTypes,
    nullptr
} };

void KDeclarativeWheelEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KDeclarativeWheelEvent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->screenX(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->screenY(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->deltaX(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->deltaY(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->deltaY(); break;
        case 7: *reinterpret_cast<Qt::MouseButtons*>(_v) = _t->buttons(); break;
        case 8: *reinterpret_cast<Qt::KeyboardModifiers*>(_v) = _t->modifiers(); break;
        case 9: *reinterpret_cast<Qt::Orientation*>(_v) = _t->orientation(); break;
        default: break;
        }
    }
}

const QMetaObject *KDeclarativeWheelEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDeclarativeWheelEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KDeclarativeWheelEventE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDeclarativeWheelEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN18MouseEventListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto MouseEventListener::qt_create_metaobjectdata<qt_meta_tag_ZN18MouseEventListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MouseEventListener",
        "QML.Element",
        "auto",
        "pressed",
        "",
        "KDeclarativeMouseEvent*",
        "mouse",
        "positionChanged",
        "released",
        "clicked",
        "pressAndHold",
        "wheelMoved",
        "KDeclarativeWheelEvent*",
        "wheel",
        "containsMouseChanged",
        "hoverEnabledChanged",
        "hoverEnabled",
        "acceptedButtonsChanged",
        "cursorShapeChanged",
        "pressedChanged",
        "canceled",
        "handlePressAndHold",
        "handleUngrab",
        "containsMouse",
        "acceptedButtons",
        "Qt::MouseButtons",
        "cursorShape",
        "Qt::CursorShape"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pressed'
        QtMocHelpers::SignalData<void(KDeclarativeMouseEvent *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(KDeclarativeMouseEvent *)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'released'
        QtMocHelpers::SignalData<void(KDeclarativeMouseEvent *)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(KDeclarativeMouseEvent *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'pressAndHold'
        QtMocHelpers::SignalData<void(KDeclarativeMouseEvent *)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'wheelMoved'
        QtMocHelpers::SignalData<void(KDeclarativeWheelEvent *)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'containsMouseChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'hoverEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'acceptedButtonsChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorShapeChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canceled'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handlePressAndHold'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleUngrab'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hoverEnabled'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'containsMouse'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'acceptedButtons'
        QtMocHelpers::PropertyData<Qt::MouseButtons>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'cursorShape'
        QtMocHelpers::PropertyData<Qt::CursorShape>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MouseEventListener, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MouseEventListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MouseEventListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MouseEventListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18MouseEventListenerE_t>.metaTypes,
    nullptr
} };

void MouseEventListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MouseEventListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pressed((*reinterpret_cast<std::add_pointer_t<KDeclarativeMouseEvent*>>(_a[1]))); break;
        case 1: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<KDeclarativeMouseEvent*>>(_a[1]))); break;
        case 2: _t->released((*reinterpret_cast<std::add_pointer_t<KDeclarativeMouseEvent*>>(_a[1]))); break;
        case 3: _t->clicked((*reinterpret_cast<std::add_pointer_t<KDeclarativeMouseEvent*>>(_a[1]))); break;
        case 4: _t->pressAndHold((*reinterpret_cast<std::add_pointer_t<KDeclarativeMouseEvent*>>(_a[1]))); break;
        case 5: _t->wheelMoved((*reinterpret_cast<std::add_pointer_t<KDeclarativeWheelEvent*>>(_a[1]))); break;
        case 6: _t->containsMouseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->hoverEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->acceptedButtonsChanged(); break;
        case 9: _t->cursorShapeChanged(); break;
        case 10: _t->pressedChanged(); break;
        case 11: _t->canceled(); break;
        case 12: _t->handlePressAndHold(); break;
        case 13: _t->handleUngrab(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeclarativeWheelEvent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(KDeclarativeMouseEvent * )>(_a, &MouseEventListener::pressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(KDeclarativeMouseEvent * )>(_a, &MouseEventListener::positionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(KDeclarativeMouseEvent * )>(_a, &MouseEventListener::released, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(KDeclarativeMouseEvent * )>(_a, &MouseEventListener::clicked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(KDeclarativeMouseEvent * )>(_a, &MouseEventListener::pressAndHold, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(KDeclarativeWheelEvent * )>(_a, &MouseEventListener::wheelMoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(bool )>(_a, &MouseEventListener::containsMouseChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)(bool )>(_a, &MouseEventListener::hoverEnabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)()>(_a, &MouseEventListener::acceptedButtonsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)()>(_a, &MouseEventListener::cursorShapeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)()>(_a, &MouseEventListener::pressedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseEventListener::*)()>(_a, &MouseEventListener::canceled, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hoverEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->containsMouse(); break;
        case 2: *reinterpret_cast<Qt::MouseButtons*>(_v) = _t->acceptedButtons(); break;
        case 3: *reinterpret_cast<Qt::CursorShape*>(_v) = _t->cursorShape(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isPressed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHoverEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setAcceptedButtons(*reinterpret_cast<Qt::MouseButtons*>(_v)); break;
        case 3: _t->setCursorShape(*reinterpret_cast<Qt::CursorShape*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 3: _t->unsetCursor(); break;
        default: break;
        }
    }
}

const QMetaObject *MouseEventListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MouseEventListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MouseEventListenerE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int MouseEventListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void MouseEventListener::pressed(KDeclarativeMouseEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MouseEventListener::positionChanged(KDeclarativeMouseEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MouseEventListener::released(KDeclarativeMouseEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MouseEventListener::clicked(KDeclarativeMouseEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MouseEventListener::pressAndHold(KDeclarativeMouseEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MouseEventListener::wheelMoved(KDeclarativeWheelEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MouseEventListener::containsMouseChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MouseEventListener::hoverEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void MouseEventListener::acceptedButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MouseEventListener::cursorShapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MouseEventListener::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MouseEventListener::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
