/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kquickcontrols()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KeySequenceEnums::staticMetaObject;},
            "KeySequenceEnums");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KeySequenceEnums::staticMetaObject, "org.kde.kquickcontrols", 2, nullptr, &Foo::staticMetaObject, nullptr);
    qmlRegisterEnum<KeySequenceEnums::ShortcutType>("KeySequenceEnums::ShortcutType");
    qmlRegisterEnum<KeySequenceEnums::ShortcutTypes>("KeySequenceEnums::ShortcutTypes");
    qmlRegisterEnum<KeySequenceEnums::ShortcutType>("KeySequenceEnums::ShortcutType");
    qmlRegisterTypesAndRevisions<KKeySequenceRecorderForeign>("org.kde.kquickcontrols", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kquickcontrols", 2, 0);
}

static const QQmlModuleRegistration orgkdekquickcontrolsRegistration("org.kde.kquickcontrols", qml_register_types_org_kde_kquickcontrols);
