/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/kquickcontrols/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27KKeySequenceRecorderForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto KKeySequenceRecorderForeign::qt_create_metaobjectdata<qt_meta_tag_ZN27KKeySequenceRecorderForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KKeySequenceRecorderForeign",
        "QML.Element",
        "ShortcutPattern",
        "QML.Foreign",
        "KKeySequenceRecorder",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Only for enums"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<KKeySequenceRecorderForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KKeySequenceRecorderForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KKeySequenceRecorderForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KKeySequenceRecorderForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27KKeySequenceRecorderForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3FooE_t {};
} // unnamed namespace

template <> constexpr inline auto Foo::qt_create_metaobjectdata<qt_meta_tag_ZN3FooE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Foo",
        "QML.Element",
        "ShortcutType",
        "QML.Foreign",
        "KeySequenceEnums",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN3FooE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN3FooE =
    Foo::qt_create_metaobjectdata<qt_meta_tag_ZN3FooE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN3FooE =
    qt_staticMetaObjectContent_ZN3FooE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN3FooE =
    qt_staticMetaObjectContent_ZN3FooE.relocatingData;

Q_CONSTINIT const QMetaObject Foo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN3FooE.stringdata,
    qt_staticMetaObjectStaticContent_ZN3FooE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN3FooE.metaTypes,
    nullptr
} };

QT_WARNING_POP
