/****************************************************************************
** Meta object code from reading C++ file 'DeclarativeMimeData.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.25.0/src/qmlcontrols/draganddrop/DeclarativeMimeData.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeclarativeMimeData.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14MimeDataForignE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeDataForign::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeDataForignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeDataForign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QMimeData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MimeDataForign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MimeDataForign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeDataForignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeDataForignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeDataForignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19DeclarativeMimeDataE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeMimeData::qt_create_metaobjectdata<qt_meta_tag_ZN19DeclarativeMimeDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeMimeData",
        "QML.Element",
        "MimeData",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "MimeData cannot be created from QML.",
        "textChanged",
        "",
        "htmlChanged",
        "urlChanged",
        "urlsChanged",
        "colorChanged",
        "sourceChanged",
        "hasColor",
        "setData",
        "mimeType",
        "QVariant",
        "data",
        "getDataAsByteArray",
        "format",
        "text",
        "html",
        "url",
        "QUrl",
        "urls",
        "QJsonArray",
        "color",
        "QColor",
        "source",
        "QQuickItem*",
        "hasUrls",
        "formats"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'htmlChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlsChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'hasColor'
        QtMocHelpers::MethodData<bool() const>(14, 8, QMC::AccessPublic, QMetaType::Bool),
        // Method 'setData'
        QtMocHelpers::MethodData<void(const QString &, const QVariant &)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Method 'getDataAsByteArray'
        QtMocHelpers::MethodData<QByteArray(const QString &)>(19, 8, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'text'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'html'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'urls'
        QtMocHelpers::PropertyData<QJsonArray>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'source'
        QtMocHelpers::PropertyData<QQuickItem*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'hasUrls'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'formats'
        QtMocHelpers::PropertyData<QStringList>(32, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeMimeData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeMimeData::staticMetaObject = { {
    QMetaObject::SuperData::link<QMimeData::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeMimeDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeMimeDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DeclarativeMimeDataE_t>.metaTypes,
    nullptr
} };

void DeclarativeMimeData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeMimeData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textChanged(); break;
        case 1: _t->htmlChanged(); break;
        case 2: _t->urlChanged(); break;
        case 3: _t->urlsChanged(); break;
        case 4: _t->colorChanged(); break;
        case 5: _t->sourceChanged(); break;
        case 6: { bool _r = _t->hasColor();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 8: { QByteArray _r = _t->getDataAsByteArray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMimeData::*)()>(_a, &DeclarativeMimeData::textChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMimeData::*)()>(_a, &DeclarativeMimeData::htmlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMimeData::*)()>(_a, &DeclarativeMimeData::urlChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMimeData::*)()>(_a, &DeclarativeMimeData::urlsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMimeData::*)()>(_a, &DeclarativeMimeData::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMimeData::*)()>(_a, &DeclarativeMimeData::sourceChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->html(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 3: *reinterpret_cast<QJsonArray*>(_v) = _t->urls(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 5: *reinterpret_cast<QQuickItem**>(_v) = _t->source(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasUrls(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->formats(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setHtml(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 3: _t->setUrls(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 4: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setSource(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeMimeData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeMimeData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativeMimeDataE_t>.strings))
        return static_cast<void*>(this);
    return QMimeData::qt_metacast(_clname);
}

int DeclarativeMimeData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMimeData::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeMimeData::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeclarativeMimeData::htmlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DeclarativeMimeData::urlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DeclarativeMimeData::urlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DeclarativeMimeData::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DeclarativeMimeData::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
