// /qt/qml/org/kde/graphicaleffects/Lanczos.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_graphicaleffects_Lanczos_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x7,0x0,0x0,0x61,0x19,0x8b,0xa1,
0xc9,0x6b,0xa7,0x6d,0x21,0x5e,0x8e,0x73,
0x53,0x92,0x9c,0x3c,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x30,0x2,0x0,0x0,
0x3,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0xd4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x5,0x0,0x0,
0x20,0x1,0x0,0x0,0x80,0x1,0x0,0x0,
0xd8,0x1,0x0,0x0,0xf3,0x0,0x0,0x0,
0x13,0x1,0x0,0x0,0x23,0x1,0x0,0x0,
0x4,0x1,0x0,0x0,0xf3,0x0,0x0,0x0,
0x34,0x1,0x0,0x0,0xf3,0x0,0x0,0x0,
0x34,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9a,0x99,0x99,0x99,0x99,0xd9,0x2c,0x40,
0x0,0x0,0x0,0x0,0x0,0x40,0x5,0x40,
0xcd,0xcc,0xcc,0xcc,0xcc,0x8c,0x11,0x40,
0x5c,0x8f,0xc2,0xf5,0x28,0x1c,0x1a,0x40,
0x44,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x25,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x25,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x18,0x7,
0x2e,0x1,0x18,0xa,0x2e,0x2,0x18,0xb,
0xac,0x3,0x7,0x2,0xa,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x42,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x42,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x4,0x18,0x7,
0x12,0x14,0x18,0xa,0xac,0x5,0x7,0x1,
0xa,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x43,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x43,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x6,0x18,0x7,
0x12,0x15,0x18,0xa,0xac,0x7,0x7,0x1,
0xa,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x88,0x2,0x0,0x0,0x90,0x2,0x0,0x0,
0xa8,0x2,0x0,0x0,0xc8,0x2,0x0,0x0,
0xe0,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0x20,0x3,0x0,0x0,0x58,0x3,0x0,0x0,
0x78,0x3,0x0,0x0,0x88,0x3,0x0,0x0,
0xb8,0x3,0x0,0x0,0xd8,0x3,0x0,0x0,
0xf8,0x3,0x0,0x0,0x38,0x4,0x0,0x0,
0x60,0x4,0x0,0x0,0xa0,0x4,0x0,0x0,
0xb0,0x4,0x0,0x0,0xc0,0x4,0x0,0x0,
0xd0,0x4,0x0,0x0,0xe8,0x4,0x0,0x0,
0x8,0x5,0x0,0x0,0x50,0x5,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x53,0x0,0x68,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x45,0x0,0x66,0x0,0x66,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x53,0x0,0x69,0x0,0x7a,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x74,0x0,0x61,0x0,
0x72,0x0,0x67,0x0,0x65,0x0,0x74,0x0,
0x53,0x0,0x69,0x0,0x7a,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x61,0x0,0x72,0x0,
0x67,0x0,0x65,0x0,0x74,0x0,0x53,0x0,
0x69,0x0,0x7a,0x0,0x65,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x53,0x0,0x69,0x0,0x6e,0x0,0x63,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x73,0x0,0x69,0x0,
0x6e,0x0,0x63,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x74,0x0,0x69,0x0,0x52,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x53,0x0,0x74,0x0,0x72,0x0,
0x65,0x0,0x6e,0x0,0x67,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x73,0x0,0x6f,0x0,0x6c,0x0,0x75,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x76,0x0,0x65,0x0,
0x72,0x0,0x74,0x0,0x65,0x0,0x78,0x0,
0x53,0x0,0x68,0x0,0x61,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x76,0x0,0x65,0x0,0x72,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x53,0x0,
0x68,0x0,0x61,0x0,0x64,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x66,0x0,0x72,0x0,
0x61,0x0,0x67,0x0,0x6d,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x53,0x0,0x68,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x72,0x0,0x61,0x0,
0x67,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x53,0x0,0x68,0x0,0x61,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x73,0x0,0x69,0x0,
0x7a,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x73,0x0,0x6f,0x0,0x6c,0x0,0x76,0x0,
0x65,0x0,0x64,0x0,0x55,0x0,0x72,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x3a,0x0,0x2f,0x0,
0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x73,0x0,0x2f,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x65,0x0,0x72,0x0,0x76,0x0,0x65,0x0,
0x61,0x0,0x73,0x0,0x70,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x2e,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x74,0x0,0x2e,0x0,
0x71,0x0,0x73,0x0,0x62,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x3a,0x0,0x2f,0x0,
0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x73,0x0,0x2f,0x0,
0x6c,0x0,0x61,0x0,0x6e,0x0,0x63,0x0,
0x7a,0x0,0x6f,0x0,0x73,0x0,0x32,0x0,
0x73,0x0,0x68,0x0,0x61,0x0,0x72,0x0,
0x70,0x0,0x2e,0x0,0x66,0x0,0x72,0x0,
0x61,0x0,0x67,0x0,0x2e,0x0,0x71,0x0,
0x73,0x0,0x62,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x28,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x7,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0xa8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa8,0x0,0x0,0x0,
0xa8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0xa8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x1,0x0,0x0,0x16,0x0,0x10,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x1,0x0,0x0,0x30,0x1a,0x0,0x50,0x0,
0x4,0x0,0x0,0x0,0xd,0x0,0x0,0x30,
0x1e,0x0,0x50,0x0,0x5,0x0,0x0,0x0,
0xd,0x0,0x0,0x20,0x25,0x0,0x50,0x0,
0x7,0x0,0x0,0x0,0x4,0x0,0x0,0x20,
0x2c,0x0,0x50,0x0,0x8,0x0,0x0,0x0,
0x4,0x0,0x0,0x20,0x32,0x0,0x50,0x0,
0x9,0x0,0x0,0x0,0x4,0x0,0x0,0x20,
0x39,0x0,0x50,0x0,0xa,0x0,0x0,0x0,
0x4,0x0,0x0,0x20,0x40,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x43,0x0,0x50,0x0,0x43,0x0,0x50,0x1,
0xb,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x42,0x0,0x50,0x0,0x42,0x0,0x30,0x1,
0xa,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x0,0x30,0x1,0x40,0x0,0xf0,0x1,
0x9,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x39,0x0,0x30,0x1,0x39,0x0,0x80,0x2,
0x8,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x32,0x0,0x30,0x1,0x32,0x0,0x90,0x1,
0x7,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2c,0x0,0x30,0x1,0x2c,0x0,0xf0,0x1,
0x5,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x25,0x0,0x30,0x1,0x25,0x0,0xf0,0x1
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QSizeF"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for targetSize at line 37, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_12, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QVariant v2_12;
double v2_4;
double v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(0, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QSizeF"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QSizeF"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(2, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QSizeF"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {callResult.data(), &s.v2_4, &s.v2_8};
    return aotContext->callObjectPropertyLookup(3, s.v2_0, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(3, s.v2_0, 14);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
callResult = QVariant(aotContext->lookupResultMetaType(3));
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QSizeF"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
callResult = QVariant(aotContext->lookupResultMetaType(3));
}
s.v2_12 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_12);
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_12.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_12.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_12.data());
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for vertexShader at line 66, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QUrl v2_4;
QUrl v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(4, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(4, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QUrl(QStringLiteral(":/shaders/preserveaspect.vert.qsb"));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QUrl callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_4};
    return aotContext->callObjectPropertyLookup(5, s.v2_0, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(5, s.v2_0, 71);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
s.v2_8 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_8);
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.v2_8);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fragmentShader at line 67, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QUrl v2_4;
QUrl v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(6, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(6, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QUrl(QStringLiteral(":/shaders/lanczos2sharp.frag.qsb"));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QUrl callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_4};
    return aotContext->callObjectPropertyLookup(7, s.v2_0, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(7, s.v2_0, 71);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
s.v2_8 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_8);
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.v2_8);
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
