/****************************************************************************
** Meta object code from reading C++ file 'keysequencehelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../kdeclarative-6.25.0/src/qmlcontrols/kquickcontrols/private/keysequencehelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keysequencehelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KeySequenceHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto KeySequenceHelper::qt_create_metaobjectdata<qt_meta_tag_ZN17KeySequenceHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeySequenceHelper",
        "QML.Element",
        "auto",
        "checkAgainstShortcutTypesChanged",
        "",
        "questionDialogAccepted",
        "questionDialogRejected",
        "updateKeySequence",
        "QKeySequence",
        "keySequence",
        "showQuestionDialog",
        "title",
        "text",
        "showErrorDialog",
        "keySequenceIsEmpty",
        "keySequenceNativeText",
        "renderWindow",
        "QWindow*",
        "QQuickWindow*",
        "quickWindow",
        "checkAgainstShortcutTypes",
        "KeySequenceEnums::ShortcutTypes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkAgainstShortcutTypesChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'questionDialogAccepted'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'questionDialogRejected'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'updateKeySequence'
        QtMocHelpers::MethodData<void(const QKeySequence &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'showQuestionDialog'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'showErrorDialog'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'keySequenceIsEmpty'
        QtMocHelpers::MethodData<bool(const QKeySequence &)>(14, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'keySequenceNativeText'
        QtMocHelpers::MethodData<QString(const QKeySequence &)>(15, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'renderWindow'
        QtMocHelpers::MethodData<QWindow *(QQuickWindow *)>(16, 4, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'checkAgainstShortcutTypes'
        QtMocHelpers::PropertyData<KeySequenceEnums::ShortcutTypes>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KeySequenceHelper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17KeySequenceHelperE[] = {
    QMetaObject::SuperData::link<KeySequenceEnums::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KeySequenceHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<KKeySequenceRecorder::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeySequenceHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeySequenceHelperE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17KeySequenceHelperE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KeySequenceHelperE_t>.metaTypes,
    nullptr
} };

void KeySequenceHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeySequenceHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkAgainstShortcutTypesChanged(); break;
        case 1: _t->questionDialogAccepted(); break;
        case 2: _t->questionDialogRejected(); break;
        case 3: _t->updateKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 4: _t->showQuestionDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->showErrorDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: { bool _r = _t->keySequenceIsEmpty((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->keySequenceNativeText((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QWindow* _r = _t->renderWindow((*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QWindow**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeySequenceHelper::*)()>(_a, &KeySequenceHelper::checkAgainstShortcutTypesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeySequenceHelper::*)()>(_a, &KeySequenceHelper::questionDialogAccepted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeySequenceHelper::*)()>(_a, &KeySequenceHelper::questionDialogRejected, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KeySequenceEnums::ShortcutTypes*>(_v) = _t->checkAgainstShortcutTypes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCheckAgainstShortcutTypes(*reinterpret_cast<KeySequenceEnums::ShortcutTypes*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeySequenceHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeySequenceHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeySequenceHelperE_t>.strings))
        return static_cast<void*>(this);
    return KKeySequenceRecorder::qt_metacast(_clname);
}

int KeySequenceHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KKeySequenceRecorder::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KeySequenceHelper::checkAgainstShortcutTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeySequenceHelper::questionDialogAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeySequenceHelper::questionDialogRejected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
